@@ -32,6 +32,7 @@ cipher_list = "ECDH+ECDSA+AESGCM:" \
 
 def reset(io: ReadingIO) -> ReadingIO:
     io.buff.seek(0)
+    return io
 
 
 def read_ssl_request(context: Context):
@@ -42,12 +43,13 @@ def read_ssl_request(context: Context):
         # Ancient: StartupMsg
 
         ssl_request = SSLRequest.read(context.input)
+        logging.error(f"read ssl request {ssl_request}")
 
         if ssl_request.request_code == 196608:
             # ancient mode
+            logging.error("reading startup message from ancient")
             return read_startup_message(context, inner_buff=reset(ssl_request.inner_buff))
         else:
-            logging.error(ssl_request)
 
             if context.key_file and context.cert_file:
                 return context.update_mem('ssl_request', ssl_request), Names.WRITE_SSL_YES
@@ -57,7 +59,7 @@ def read_ssl_request(context: Context):
     except Exception as e:
         log_exception(e)
         logging.error("Error while processing ssl request, downgrading to SSL_NO")
-        return context, Names.WRITE_SSL_NO
+        return context, Names.CLOSE
 
 
 def write_ssl_resp_no(context: Context):
